#
# spec file for package courier-imap
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           courier-imap
Summary:        An IMAP and POP3 Server for Maildir MTAs
License:        GPL-3.0+
Group:          Productivity/Networking/Email/Servers
Version:        4.16.2
Release:        2.40
Url:            http://www.courier-mta.org/imap/
Source0:        %{name}-%{version}.tar.bz2
Source1:        %{name}-%{version}.tar.bz2.sig
Source2:        pop3.pamd
Source3:        imap.pamd
Source4:        %{name}.firewall
Source5:        %{name}-ssl.firewall
Source11:       courier-imap.init
Source12:       courier-imap-ssl.init
Source13:       courier-pop.init
Source14:       courier-pop-ssl.init
Source15:       courier-imap.service
Source16:       courier-imap-ssl.service
Source17:       courier-imap-gencert.service
Source18:       courier-pop.service
Source19:       courier-pop-ssl.service
Source20:       courier-pop-gencert.service
Patch0:         %{name}-sbindir.patch
Patch2:         %{name}-ulimit_conf.patch
### Patch for upstream:
## fixes typo in Makefile.am
Patch3:         %{name}-Makefile.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 910
BuildRequires:  audit-libs
%endif
BuildRequires:  courier-authlib-devel >= 0.62
BuildRequires:  courier-unicode-devel
BuildRequires:  db-devel
%if 0%{?suse_version} >= 1220
BuildRequires:  gamin-devel
%else
BuildRequires:  fam-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  gdbm-devel
BuildRequires:  libstdc++-devel
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  postfix
BuildRequires:  procps
BuildRequires:  zlib-devel
# openssl itself for /usr/bin/openssl configure check
BuildRequires:  openssl
Conflicts:      imap qpopper cyrus-imapd
Requires:       courier-authlib >= 0.62
Requires:       fam-server
Requires:       gdbm
Requires:       openssl

%if 0%{?suse_version} >= 1210
BuildRequires:  systemd
%{?systemd_requires}
%define has_systemd 1
%endif

%description
Courier-IMAP is a fast, scalable, enterprise IMAP server that uses
Maildirs. Many E-mail service providers use Courier-IMAP to easy handle
hundreds of thousands of mail accounts. With its built-in IMAP and POP3
aggregation proxy, Courier-IMAP has practically infinite horizontal
scalability. In a proxy configuration, a pool of Courier servers service
initial IMAP and POP3 connections from clients. They wait to receive the
client's log in request, look up the server that actually holds this mail
account's mailbox, and establish a proxy connection to the server, all in
a single, seamless process. Mail accounts can be moved between different
servers, to achieve optimum resource usage.

The only practical limitation on Courier-IMAP is available network and I/O
bandwidth. If you are new to Courier-IMAP, this may sound a bit
intimidating. But you do not need to tackle everything at once. Start by
taking small, easy steps. Your first step will be to set up a small
Courier-IMAP server, using it like any other traditional IMAP service, on
a single server. After you gain experience and become comfortable with
Courier, you can then begin exploring its advanced features.

This is the same IMAP server that's included in the Courier mail server,
but configured as a standalone IMAP server that can be used with other
mail servers - such as Qmail, Exim, or Postfix - that deliver to maildirs.
If you already have Courier installed, you do not need to download this
version. If you install this version, you must remove it if you later
install the entire Courier server.


%prep
%setup -n %{name}-%{version}
%patch0
%patch2
%patch3

%build
%configure \
	--libexecdir=%{_prefix}/lib/%{name} \
	--datadir=%{_datadir}/%{name} \
	--sysconfdir=%{_sysconfdir}/courier \
	--sharedstatedir=%{_sharedstatedir}/%{name} \
%if 0%{?has_systemd}
	--with-piddir=/run \
%else
	--with-piddir=%{_localstatedir}/run \
%endif
	--disable-static \
	--disable-root-check \
	--enable-unicode \
%if 0%{?has_systemd}
	--with-authdaemonvar=/run/courier-authlib \
%else
	--with-authdaemonvar=%{_localstatedir}/run/courier-authlib \
%endif
	--with-certdb=%{_sysconfdir}/ssl/certs \
	--with-certsdir=%{_sysconfdir}/ssl/private \
	--enable-workarounds-for-imap-client-bugs
%{__make} %{_smp_mflags}

%install
%{__make} install DESTDIR=%{buildroot}
# Move daemons into sbin
%{__mv} %{buildroot}%{_prefix}/bin/{couriertls,imapd,pop3d} %{buildroot}%{_prefix}/sbin/
# Rename imapd.8 to courier-imapd.8
%{__mv}  %{buildroot}%{_mandir}/man8/imapd.8 %{buildroot}%{_mandir}/man8/%{name}d.8
# Install PAM config files
%{__install} -D -m 644 $RPM_SOURCE_DIR/pop3.pamd %{buildroot}/etc/pam.d/pop3
%{__install} -D -m 644 $RPM_SOURCE_DIR/imap.pamd %{buildroot}/etc/pam.d/imap
# Install init scripts
for i in imap imap-ssl pop pop-ssl ; do
  %{__install} -D -m 0755 $RPM_SOURCE_DIR/courier-$i.init %{buildroot}/etc/init.d/courier-$i
  %{__ln_s} -f /etc/init.d/courier-$i %{buildroot}%{_prefix}/sbin/rccourier-$i
done
# Install service files
%if 0%{?has_systemd}
for j in imap imap-ssl imap-gencert pop pop-ssl pop-gencert; do
  %{__install} -D -m 0644 $RPM_SOURCE_DIR/courier-$j.service %{buildroot}/%{_unitdir}/courier-$j.service
done
%endif
# Remove original init scripts, will not work longer
%{__rm} %{buildroot}%{_prefix}/lib/%{name}/imapd.rc
%{__rm} %{buildroot}%{_prefix}/lib/%{name}/imapd-ssl.rc
%{__rm} %{buildroot}%{_prefix}/lib/%{name}/pop3d.rc
%{__rm} %{buildroot}%{_prefix}/lib/%{name}/pop3d-ssl.rc
#
# Fix imapd.dist
#
%{__sed} -i -e 's/^IMAPDSTART=.*/IMAPDSTART=YES/' %{buildroot}%{_sysconfdir}/courier/imapd.dist
%{__sed} -i -e 's/^ADDRESS=.*/ADDRESS=127.0.0.1/' %{buildroot}%{_sysconfdir}/courier/imapd.dist
%{__sed} -i -e 's/^MAXPERIP=.*/MAXPERIP=20/' %{buildroot}%{_sysconfdir}/courier/imapd.dist
%{__sed} -i -e 's/^IMAPDSSLSTART=.*/IMAPDSSLSTART=YES/' %{buildroot}%{_sysconfdir}/courier/imapd-ssl.dist
#%{__sed} -i -e 's/^#\ \+\(TLS_CIPHER_LIST=.*\)/\1/' %{buildroot}%{_sysconfdir}/courier/imapd-ssl.dist
%{__sed} -i -e 's/^POP3DSTART=.*/POP3DSTART=YES/' %{buildroot}%{_sysconfdir}/courier/pop3d.dist
%{__sed} -i -e 's/^POP3DSSLSTART=.*/POP3DSSLSTART=YES/' %{buildroot}%{_sysconfdir}/courier/pop3d-ssl.dist
#%{__sed} -i -e 's/^#\ \+\(TLS_CIPHER_LIST=.*\)/\1/' %{buildroot}%{_sysconfdir}/courier/pop3d-ssl.dist
# For %doc macro
%{__install} -m 0644 libs/imap/ChangeLog ChangeLog
%{__install} -m 0644 libs/imap/README README.imap
%{__install} -m 0644 libs/imap/README.proxy README.proxy
%{__install} -m 0644 libs/maildir/README.maildirquota.txt README.maildirquota
%{__install} -m 0644 libs/maildir/README.sharedfolders.txt README.sharedfolders
%{__install} -D -m 0755 sysconftool %{buildroot}%{_datadir}/%{name}/sysconftool
%{__chmod} 755 %{buildroot}%{_datadir}/%{name}/sysconftool
%{__cat} >%{buildroot}%{_datadir}/%{name}/configlist <<EOF
%{_sysconfdir}/courier/imapd.dist
%{_sysconfdir}/courier/imapd-ssl.dist
%{_sysconfdir}/courier/pop3d.dist
%{_sysconfdir}/courier/pop3d-ssl.dist
EOF
#firewall script
%{__install} -D -m 644 %{S:4} %{buildroot}%{_sysconfdir}/SuSEfirewall2.d/services/%{name}
%{__install} -D -m 644 %{S:5} %{buildroot}%{_sysconfdir}/SuSEfirewall2.d/services/%{name}-ssl

%pre
%if 0%{?has_systemd}
for i in imap imap-ssl imap-gencert pop pop-ssl pop-gencert; do
  %service_add_pre courier-$i.service
done
%endif

%preun
%if 0%{?suse_version}
for i in imap imap-ssl pop pop-ssl; do
  %stop_on_removal courier-$i
done
%endif
%if 0%{?has_systemd}
for i in imap imap-ssl imap-gencert pop pop-ssl pop-gencert; do
  %service_del_preun courier-$i.service
done
%endif
if [ "$1" = "0" ]; then
  %{__rm} -f %{_localstatedir}/couriersslcache
  %{__rm} -f %{_localstatedir}/imapd.pid
  %{__rm} -f %{_localstatedir}/imapd-ssl.pid
  %{__rm} -f %{_localstatedir}/imapd.pid.lock
  %{__rm} -f %{_localstatedir}/imapd-ssl.pid.lock
  %{__rm} -f %{_localstatedir}/pop3d.pid
  %{__rm} -f %{_localstatedir}/pop3d-ssl.pid
  %{__rm} -f %{_localstatedir}/pop3d.pid.lock
  %{__rm} -f %{_localstatedir}/pop3d-ssl.pid.lock
fi

%post
%{_datadir}/%{name}/sysconftool `%{__cat} %{_datadir}/%{name}/configlist` >/dev/null

%if 0%{?has_systemd}
for i in imap imap-ssl imap-gencert pop pop-ssl pop-gencert; do
  %service_add_post courier-$i.service
done
%endif

%postun
for i in imap imap-ssl pop pop-ssl; do
  %restart_on_update courier-$i
done  
%insserv_cleanup
%if 0%{?has_systemd}
for i in imap imap-ssl imap-gencert pop pop-ssl pop-gencert; do
  %service_del_postun courier-$i.service
done
%endif

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-,root,root,755)
%doc AUTHORS libs/imap/ChangeLog COPYING* libs/imap/BUGS README README.imap README.maildirquota README.proxy
%doc README.sharedfolders
%attr(755,root,root) /etc/init.d/courier-*
%config %attr(644,root,root) /etc/pam.d/imap
%config %attr(644,root,root) /etc/pam.d/pop3
%dir %{_sysconfdir}/courier
%dir %{_sysconfdir}/courier/imapaccess
%dir %{_sysconfdir}/courier/shared
%dir %{_sysconfdir}/courier/shared.tmp
%config %attr(600,root,root) %{_sysconfdir}/courier/imapd*
%config %attr(600,root,root) %{_sysconfdir}/courier/pop3*
%config %{_sysconfdir}/courier/quotawarnmsg.example
%dir %{_sysconfdir}/SuSEfirewall2.d
%dir %{_sysconfdir}/SuSEfirewall2.d/services
%config %{_sysconfdir}/SuSEfirewall2.d/services/%{name}
%config %{_sysconfdir}/SuSEfirewall2.d/services/%{name}-ssl
%dir %{_prefix}/lib/%{name}
%{_prefix}/lib/%{name}/makedatprog
%{_prefix}/lib/%{name}/couriertcpd
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/*
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man?/*
%if 0%{?has_systemd}
%{_unitdir}/courier-*.service
%endif

%changelog
* Wed Aug  5 2015 chris@computersalat.de
- update to 4.16.2
  * imap/mailboxlist.c (match_mailbox_prep): Use strncmp instead of
    memcmp, to pacify overzealous static analysis checkers.
  * Drop SSLv3 from TLS_CIPHER_LIST.
  * imap, pop3: Added AUTH_MKHOMEDIR_SKEL setting.
- update to 4.16.1
  * maildircache.c: fix use after free.
  * mkdhparams: make compatible with libressl
  * Handle 01-Jan-1970 for date-based searches.
  * Update to courier-unicode 1.2.
  * Add the makeimapaccess script.
- add Patch courier-imap-Makefile.patch
* Wed Oct 29 2014 chris@computersalat.de
- update to 4.15.1.20141122
  * tcpd/libcouriertls.c: add parsing options for different protocol
    combination.
  * Update comments in *ssl config files.
  * libs/tcpd/libcouriertls.c (tls_create): Set SSL_OP_NOSSLv3 flag,
    to disable SSL3 support.
  * mkdhparams: TLS_DHPARAMS environmnt variable overrides default
    DH parameter file location.
  * courier-imap.spec.in: generate the default DH parameter file and
    package it into the rpm, instead of generating one on the first
    start.
  * libs/maildir/maildirinfo.c (maildir_info_imapmunge): Fix
    UTF-8 charset name.
  * tcpd/libcouriertls.c (tls_create): Initialize temporary ecdh
    parameters.
  * imap: try to print a message on stderr if the alarm() call, that
    detects FAM library breakage, goes off.
  * mkdhparams: default to 2048 DH params for OpenSSL.
  * courier-imap.service: bump up startup timeout, initial service start
    may take several minutes to generate DH parameters for the first
    time.
- add new dependency
  * courier-unicode-devel (libunicode)
* Thu Sep 25 2014 chris@computersalat.de
- fix courier-imap.service
  * STARTTLS on port 143 (thanks to cschweingruber)
* Sat Mar 15 2014 chris@computersalat.de
- update to 4.15
  * pop3login.c (starttls): Clear input buffer after STARTTLS.
  * imaplogin.c (starttls): Clear input buffer after STARTTLS.
  * Fix various compiler warnings about unchecked results from setuid
    and setgid calls.
  * libs/tcpd/libcouriergnutls.c, libs/tcpd/libcouriertls.c: remove the
    TLS_DHCERTFILE setting, and use TLS_CERTFILE for all functionality.
    Read DH parameters from TLS_CERTFILE, or from the new TLS_DHPARAMS
    environment variable.
  * mkdhparams: New script that generates DH parameters into a standalone
    file.
  * Remove TLS_DHCERTFILE setting from imapd-ssl, pop3d-ssl, esmtpd and
    esmtpd-ssl. Add TLS_DHPARAMS.
  * Update imapd.cnf.openssl, pop3d.cnf.openssl, esmtpd.cnf.openssl,
    set default number of bits for RSA keys to 4096.
  * libs/tcpd/libcouriertls.c (tls_create): Add TLSv1_1_method() and
    TLSv1_2 method(), based on patch by Rob Austein <sra@hactrn.net>.
  * pop3d-ssl.dist.in, imapd-ssl.dist.in: Fix up differences in the
    documentation of TLS options in various config files.
- added systemd service files
- fix build for SLE
  * fam-devel vs gamin-devel
- cleanup spec
  * RPM_BUILD_ROOT -> buildroot
* Wed Jan  8 2014 adrian@suse.de
- use gamin-devel instead of unmaintained fam(-devel) package
* Mon Nov 11 2013 chris@computersalat.de
- update to 4.14.0
  * Autotool chain update.
  * imapd.c (mddelete): Reject DELETE folder if the maildir is a symlink.
  * imapd.c (doId): Implement the IMAP ID EXTENSION.
- 4.13.0
  * imap: add explicit mkdirs on PIDFILE directories to startup scripts.
  * rfc822: workaround for invalid utf-8 input making libidn go off the
    rails.
- fix License
  * GPL-3.0 -> GPL-3.0+
- rebase patches
  * imap-sbindir, imap-ulimit_conf
* Tue Jan 15 2013 chris@computersalat.de
- update to 4.12.0
  * tcpd/libcouriergnutls.c (get_server_cert): Fix size of malloced
    buffer.
  * configure.in: Fix typo in configure check for setvbuf().
- rebase patches
  * sbindir (remove version), ulimit_conf (rename diff -> patch)
* Fri Sep 21 2012 chris@computersalat.de
- update to 4.11.0
  * maildir/maildiraclt.c (maildir_acl_delete): Fix double-free on error
    path of an ENOMEM.
  * courier.spec.in: Fix the RPM spec to work around /bin symlink
    breakage in F17.
  * tcpd/tcpd.c: Update libgnutls API, replace obsoleted functions
    with current API. Obsoletes most TLS_* variables that set protocol
    priorities, replaced with Gnutls-specific single TLS_PRIORITY
    setting (existing TLS_* variables are still used by the OpenSSL
    alternative). Updated *-ssl configuration files accordingly.
  * tcpd: Compilation changes for gnutls 3
  * liblock/mail.c (dotlock_exists): Quell a compiler warning.
  * Miscellaneous spelling fixes.
- rebase sbindir patch (4.8.0 -> 4.11.0)
* Sat Jan  7 2012 chris@computersalat.de
- update to 4.10.0
  * imapd.c (main): Open IMAPDEBUGFILE only if it exists already.
    (do_expunge): Optionally log deletions. Based on a patch by
    William Yodlowsky <wyodlows@andromeda.rutgers.edu>.
  * pop3dserver.c (cleanup): Optionally log deletions. Based on a patch by
    William Yodlowsky <wyodlows@andromeda.rutgers.edu>.
  * imapd.dist.in (IMAP_MOVE_EXPUNGE_TO_TRASH): Officially document how
    IMAPDEBUGFILE works.
  * imapscanclient.c: Postpone Y2038K for a while, for uid validities.
  * liblock/mail.c (dotlock_exists): Handle getting here because of a
    recycled pid.
  * unicode/unicode.c (init_default_chset): Handle NULL from setlocale().
  * rfc2045/reformime.c (main2): Fixed segfault on some arches from an
    initial null given to strtok.
  * rfc2045/reformime.c (main2): On ia64 and arm, argv is in readonly
    memory.
  * pop3dserver.c (openpop3dlist): Try a few times to reopen pop3dsizelist
    if it fails with ESTALE.
  * pop3d.dist.in: Add AUTHSERVICE settings. They've been supported
    all along.
  * Fix gcc 4.6 warnings
  * courier-imap.spec.in: switch to systemd. Remove script used when
    upgrading from ancient pre-sysconftool versions.
  * Fix autoconf warnings.
* Wed Sep 21 2011 chris@computersalat.de
- change --with-authdaemonvar to /var/run/courier-authlib
* Fri May 27 2011 chris@computersalat.de
- update to 4.9.3
  * msgenvelope.c (msgappends): Fix a fatal error upon encountering
    8-bit header content. Heuristically try to interpret it as UTF-8, and
    just ignore invalid UTF-8 sequences.
  - 4.9.2
  * rfc2045/rfc2045cdecode.c: Tolerate lowercase hexadecimal characters
    in quoted-printable-encoded content.
  * unicode/unicode.c: Compilation fixes.
* Sun May  1 2011 chris@computersalat.de
- update to 4.9.1
  * tcpd/libcouriertls.c (tls_create): Remove SSLv2_method().
    (tls_create): Remove "!SSLv2" from the default TLS_CIPHER_LIST.
  * mkimapdcert.in (prefix): Create imapd.pem with 600 perms.
  * mkpop3dcert.in (prefix): Create pop3d.pem with 600 perms.
- for more info please see Changelog file
- fix License
  o GPLv2+ -> GPLv3
- fix path to ChangeLog file
* Mon Oct 11 2010 chris@computersalat.de
- update to 4.8.1
  * Makefile.am (imapd.cnf): Compatibility fixes.
- 2010-08-15  Sam Varshavchik  <mrsam@courier-mta.com>
  * maildir/maildirwatch.c (maildirwatch_alloc): Use alarm() to kill
    the process if FAMOpen() takes more than 15 seconds to return.
    Should prevent a hung process if FAM/Gamin is fubared.
- 2010-07-11  Sam Varshavchik  <mrsam@courier-mta.com>
  * pop3dserver.c: Make printed() and putchar() macros.
- 2010-07-01  Sam Varshavchik  <mrsam@courier-mta.com>
  * imapd.cnf pop3d.cnf (default_md): added default_md = sha1
- 2010-06-28  Sam Varshavchik  <mrsam@courier-mta.com>
  * rfc822/rfc822.c (rfc822_print_common_nameaddr): Prevent segfault if
    address decode fails.
  * Fix make check failure when libidn is not available.
- 2010-05-31  Sam Varshavchik  <mrsam@courier-mta.com>
  * Rebuilt man pages with updated stylesheets.
- remove obsolete certsdir patch
- remove LDFLAGS patch, add configure option --disable-static
* Thu Aug  5 2010 chris@computersalat.de
- have pop3d, imapd ssl certs in /etc/ssl/private
  [bnc#628487]; certsdir patch
* Mon Jul  5 2010 chris@computersalat.de
- update to 4.8.0
  * tcpd/configure.in: Check if explicit linking with libgpg-error is
    required.
- 2010-03-20  "Stefan Hornburg (Racke)" <racke@linuxia.de>
  * imapd.c (main): Fix typo in alert message.
- 2010-03-18  Hugo Monteiro <hugo.monteiro@fct.unl.pt>
  * Big quota patch (with some changes).
- 2010-03-12  Sam Varshavchik  <mrsam@courier-mta.com>
  * imapd.c (main): Dummy FAM/Gamin initialization, report an error
    during login, upon a failure.
- 2010-03-10  Sam Varshavchik  <mrsam@courier-mta.com>
  * imapd.c (imapenhancedidle): Make FAM error more meaningful.
- 2010-02-25  Bernard Quatermass <bernard@quatermass.co.uk>
  * pop3dserver.c (main): "disableinsecurepop3" account option disables
    non-SSL logins.
  * imapd.c (chkdisabled): "disableinsecureimap" account option disables
    non-SSL logins.
- reworked sbindir patch
* Sat Jul  3 2010 meissner@suse.de
- buildrequire openssl so configure finds /usr/bin/openssl bnc#619665
* Mon May 17 2010 chris@computersalat.de
- fix path to TLS_TRUSTCERTS (imap-ssl,pop3d-ssl)
  o added --with-certdb=%%{_sysconfdir}/ssl/certs
* Wed Feb 24 2010 chris@computersalat.de
- update to 4.7.0
  * lot of changes, see ChangeLog
- reworked LDFLAGS patch (fuzz 0)
* Tue Oct  6 2009 chris@computersalat.de
- update to 4.6.0
  * outbox.c (imapd_sendmsg): Renamed sendmsg() to avoid library name
    clash.
  * tls: change the default OpenSSL configuration to disable anonymous
    authentication ciphers
* Sat Sep  5 2009 chris@computersalat.de
- spec mods
  o resorted Tags
* Sat Sep  5 2009 chris@computersalat.de
- update to 4.5.1
  * all: gcc 4.4 fixes
  * fetch.c (open_cached_fp): If the message file cannot be opened,
    create a dummy message in its place.
- spec mods
  o added missing norootforbuild
  o fix patch naming patch0
- mod to imapd.dist
  o increased MAXPERIP from 10 to 20
    thunderbird does 5 con per account, if not known by user
    he will come into trouble
* Wed Aug 26 2009 chris@computersalat.de
- spec mods
  o fix typo missing '%%'if
* Thu Aug 20 2009 chris@computersalat.de
- cleanup spec file
  o removed all #---- lines
  o added configure macro
- merge .spec with o:F
- merge .changes with o:F
* Thu Aug 20 2009 opensuse@cboltz.de
- read ssl config files in non-ssl initscripts if TLS is enabled
  [bnc#420972#c2]
* Tue Jul  7 2009 chris@computersalat.de
- fixed self prov error (imap)
* Sun May 24 2009 chris@computersalat.de
- new version 4.5.0
  o Documentation refresh.
  o pop3dserver.c: s/POP3_STLS/POP3_TLS/, for correct logging.
  o imaprefs.c (dorefcreate): Clean up usage of rfc822_threadsearchmsg().
    A malloc() failure wasn't checked correctly.
  o rfc2045/rfc2045_fromfd.c: Optimize header parsing.
  o search.c: Empty MIME entities would always match any SEARCH. Reported
    by Dmitry Osipov.
  o tcpd/configure.in: --without-gnutls forces suppression of GnuTLS when
    OpenSSL is not present.
  o tcpd/libcouriergnutls.c (tls_connect): Fix client certificate request
    settings.
  o tcpd/libcouriergnutls.c (set_cert): Add support for certificates
    signed by an intermediate CA.
  o imapwrite.c (write_error_exit): Dump fatal errors to stderr.
- new sbindir (failed), LDFLAGS (hunk) patch
- some spec fixes
  o updated header
  o updated description
  o added ChangeLog, README.proxy
  o fixed init install (0755)
  o conflicts with cyrus-imapd
- fixed init scripts
  o removed X-United stuff
- rpmlint stuff
  o install-no-mkdir-buildroot
  o removed old Obsoletes
  o fixed non-conffile-in-etc
* Sat May 23 2009 chris@computersalat.de
- fixed differences of changelog
  o my fault, added changes to spec, now fixed :)
* Sat Nov 15 2008 chris@computersalat.de
- some rpmlint stuff
  o modified post: insserv courier-*
* Tue Sep 16 2008 hvogel@suse.de
- Fix init scripts without ssl to not include ssl config files
  [bnc#420972]
* Fri Sep 12 2008 hvogel@suse.de
- Fix protocol names in firewall service files [bnc#425216]
* Mon Sep  8 2008 hvogel@suse.de
- update to 4.4.1
  * Update descriptions of maildir quotas
  * Use the couriertls library to invoke couriertls. SASL
    authentication did not correctly handle the special case of "="
    passed as the initial response to indicate an empty initial
    response. Switch to the new auth_sasl_ex() API.
  * Check the environment variables for subject fields set by
    couriertls. Advertise the AUTH EXTERNAL capability, if they
    are set.
  * Optimize IMAP keyword implementation. Faster results in exchange
    for a concurrency tradeoff if two concurrent sessions attempt to
    update keywords for the same message at the same time
  * Backslashed special characters in address names weren't being
    dequoted correctly
  * Add a timeout to the POP3 login stage
  * Fix SSL initialization
  * Fix TLS session caching
* Mon Apr 14 2008 aj@suse.de
- Remove executable permissions from README files.
* Wed Apr  2 2008 hvogel@suse.de
- update to version 4.3.1
  * make SSL23 default tls protocol
  * update description of SSL/TLS-related settings
  * introduce IMAP_MAILBOX_SANITY_CHECK
  * Explicitly make stderr line-buffered
  * Suppress spurious error message in imap.c
- fix some rpmlint warnings
* Thu Jan 17 2008 mskibbe@suse.de
- update to version 4.3.0 which
  o Fix some Bugs
  o Fix SSL session caching bug
  o Make skew check more reliable
  o code cleanup
* Wed Nov 21 2007 mskibbe@suse.de
- Bug 342601 - courier-imap rc and config bugs
* Fri Nov 16 2007 mskibbe@suse.de
- Bug 341267 - courier-imap-ssl configuration problems
* Mon Oct 22 2007 sbrabec@suse.cz
- Use correct SuSEfirewall2 rule directory.
* Wed Apr 25 2007 mskibbe@suse.de
- update to version 4.1.3 which includes:
  o fix memory leak
  o checks for malloc failures
  o updated man pages
  o cleaned up configure script
  o bug fixes
* Mon Apr 23 2007 mskibbe@suse.de
- SuSEfirewall2 service file installed in wrong dir/broken
  (#266949)
* Thu Mar 29 2007 rguenther@suse.de
- add procps BuildRequries because of interesting configure checks
* Mon Mar 26 2007 rguenther@suse.de
- add gdbm-devel BuildRequires
* Wed Mar 14 2007 mskibbe@suse.de
- fam has no address, rejected by xinetd, when called from
  courier-imap (#253437)
* Fri Mar  2 2007 mskibbe@suse.de
- courier : Support for FATE #300687: Ports for SuSEfirewall added
  via packages (#250575)
- fix file list
- update to version 2.1.2 which
  o Clarify some error messages
  o Try to log bandwidth usage before getting killed by a signal
  o Fix many compiler warnings
  o Fix segfault if non-cert files were found in the cert dir
  o Added koi8-u character set
* Mon Feb 12 2007 mskibbe@suse.de
- fix mkpop3dcert and mkimapdcert. Now they use pem files from
  /etc/courier-imap/
* Mon Feb  5 2007 mskibbe@suse.de
- Courier generates certificates in /usr/share/courier-imap
  (#241937)
* Mon Jan 22 2007 mskibbe@suse.de
- checkproc uses -p parameter not as specified in man page
  (#230806)
* Mon Sep 11 2006 tpatzig@suse.de
- Add Conflict to qpopper
* Tue Aug  1 2006 mskibbe@suse.de
- update to version 4.1.1 which
  o fixed some compiler warnings
  o fix segfault if non-cert files were found in the cert dir
  o Added koi8-u character set
  o fix quota calculations on 32 bit platforms with 64 bit off_t
  o Don't assume that connect() of a non-blocking socket always
    fails with INPROGRESS
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec  6 2005 kukuk@suse.de
- Don't link static
* Mon Nov 14 2005 kukuk@suse.de
- Add postfix to nfb to fix location of sendmail [#133327]
* Wed Nov  2 2005 kukuk@suse.de
-  Update to version 4.0.6
* Fri Sep 23 2005 kukuk@suse.de
- Fix imapd and pop3d init scripte for SSL connections [#113213]
* Mon Sep 19 2005 kukuk@suse.de
- Update to version 4.0.5
* Fri Aug 26 2005 kukuk@suse.de
- Rename courier-pop3* init scripts to courier-pop* to be
  LSB conform
- Source imapd-ssl and pop3-ssl from init scripts [#113213],
  use correct SSLPIDFILE variable and add path to checkproc
* Wed Aug  3 2005 kukuk@suse.de
- Update to version 4.0.4
* Thu Jul 21 2005 kukuk@suse.de
- Use Maildir from config file [#94231]
- If user removed PIDFILE entry from config file, set default
  one [#85845]
* Thu Nov 18 2004 kukuk@suse.de
- Update to release 3.0.8
* Mon Nov 15 2004 kukuk@suse.de
- Use common-* PAM config files for imap and pop3
* Mon Sep  6 2004 kukuk@suse.de
- Fix permission of /usr/lib/courier-imap/authlib/authdaemond.ldap
  [#44721]
* Mon Aug 16 2004 kukuk@suse.de
- Update to bug fix release 3.0.7
* Wed May 12 2004 kukuk@suse.de
- Update to 3.0.3
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Wed Mar 17 2004 kukuk@suse.de
- Update to 3.0.2: vpopmail password fixes, filesystem/ACL fixes
* Mon Mar  8 2004 kukuk@suse.de
- Update to official 3.0.0 release
* Mon Feb  9 2004 kukuk@suse.de
- Update to official 2.2.1 release
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 29 2003 kukuk@suse.de
- Add conflict with imap package
* Tue Aug 26 2003 kukuk@suse.de
- Fix typo in spec file
- Update to 2.1.1
* Sun Aug  3 2003 aj@suse.de
- Package sysconftool also.
* Fri Aug  1 2003 kukuk@suse.de
- Rename imapd.8 to courier-imapd.8 to resolve file conflicts.
* Wed Jul 30 2003 kukuk@suse.de
- Initial version
